@@ -128,8 +128,10 @@ def install():
 
         # Install Docker if not available
 
-        docker_install_script_path = os.path.join(absolute_package_path, "scripts", "docker-install.sh")
-        docker_compose_install_script_path = os.path.join(absolute_package_path, "scripts", "docker-compose-install.sh")
+        docker_install_script_path = os.path.join(
+            absolute_package_path, "scripts", "docker-install.sh")
+        docker_compose_install_script_path = os.path.join(
+            absolute_package_path, "scripts", "docker-compose-install.sh")
 
         if is_installed("docker"):
             echo("Docker is already installed.")
@@ -391,7 +393,7 @@ def init(store_name: str, template: str = "default"):
 
 
 @app.command()
-def setup():
+def setup(store_url: str = "https://store-new.accoladez.com", auth_url: str = "https://auth.accoladez.com"):
     """
     Setup the store.
     """
@@ -433,20 +435,18 @@ def setup():
 
             if verify_dns_record(hosted_zone_id, 'A', auth_service_domain, machine_ip_address):
                 echo(
-                    f"💾 Auth service domain {auth_service_domain} is verified.")
+                    f"✅ Auth service domain {auth_service_domain} is verified.")
             else:
                 echo(
-                    f"💾 Auth service domain {auth_service_domain} is not verified.")
-                raise typer.Abort(
-                    f"💥 Auth service domain {auth_service_domain} is not verified.")
+                    f"❌ Auth service domain {auth_service_domain} is not verified.")
+                raise typer.Abort()
             if verify_dns_record(hosted_zone_id, 'A', store_service_domain, machine_ip_address):
                 echo(
-                    f"💾 Store service domain {store_service_domain} is verified.")
+                    f"✅ Store service domain {store_service_domain} is verified.")
             else:
                 echo(
-                    f"💾 Store service domain {store_service_domain} is not verified.")
-                raise typer.Abort(
-                    f"💥 Store service domain {store_service_domain} is not verified.")
+                    f"❌ Store service domain {store_service_domain} is not verified.")
+                raise typer.Abort()
 
             ACCOLADEZ_APP_ID = generate_store_app_id(parsed_store_name)
             ACCOLADEZ_APP_SECRET = generate_store_app_key(parsed_store_name)
@@ -545,7 +545,8 @@ def setup():
 
                 # Auth Frontend Config
 
-                AUTH_FRONTEND_URL = input("Enter the Auth Frontend URL: ")
+                # AUTH_FRONTEND_URL = input("Enter the Auth Frontend URL: ")
+                AUTH_FRONTEND_URL = auth_url
                 dotenv.set_key(auth_env_path,
                                "BASE_URL", AUTH_FRONTEND_URL)
 
@@ -558,7 +559,8 @@ def setup():
 
                 # CORS Config
 
-                STORE_FRONTEND_URL = input("Enter the Store Frontend URL: ")
+                # STORE_FRONTEND_URL = input("Enter the Store Frontend URL: ")
+                STORE_FRONTEND_URL = store_url
 
                 CORS_ALLOWED_ORIGINS = [
                     STORE_FRONTEND_URL,
