@@ -2,7 +2,7 @@ import subprocess
 
 
 def restart_nginx():
-    subprocess.call("sudo service nginx restart", shell=True)
+    subprocess.call("sudo systemctl restart nginx", shell=True)
     return True
 
 def verify_nginx_conf():
